define(["app", "js/models/classificaModel", "js/models/squadraModel", "js/classifiche/classificheView", "text!js/homepage/list.html"], function(app, Classifica, Squadra, ClassificheView, ListTemplate) {
	var campionato = "";
	var modulo = "";
	var cuore = false;
	var classifiche = [];
	var bindings = [{
		element : '.squadra-preferita',
		event : 'change',
		handler : setSquadraPreferita
	}];

	function init(query) {
		if(app.utils.checkConnection() == true) {
			campionato = query.Campionato;
			modulo = query.modulo;
			app.utils.Log("INIT classificheController");
	
			if (query.container == undefined) {
				container = false;
			} else {
				container = query.container;
			}
	
			var compiled_template = Template7.compile(ListTemplate);
			var html = compiled_template({
				"modulo" : modulo,
				"notifiche" : app.utils.getClassNotifiche
			});
			if (!container) {
				cuore = false;
				app.mainView.router.loadPage({
					content : html
				});
			} else {
				cuore = true;
				container.router.loadPage({
					content : html
				});
			}		
			
			app.f7.showIndicator();
			loadClassifiche("", false);
	
			$('.pull-to-refresh-content' + '.' + modulo + '-refresh').bind('refresh', function(e) {
				e.stopPropagation();
				refreshResults();
			});
			
			$('#refresh_link_' + modulo).bind('click', function(e) {
				e.stopPropagation();
				refreshResults();
			});
	
			app.utils.googleAnalytics('send', 'pageview', {
				'page' : getHeader()
			});
		} else {
			app.utils.ajaxError();
		}
	}

	function getHeader() {
		var header = "";
		switch (campionato) {
			case "A1" :
				header = "Classifica Regular Season A1";
				break;
			case "A2" :
				header = "Classifica Regular Season A2";
				break;
			case "A1Femminile" :
				header = "Classifica Regular Season A1 Femminile";
				break;
			case "A2Femminile" :
				header = "Classifica Regular Season A2 Femminile";
				break;
			default :
				break;
		}
		return header;
	}
	
	function setSquadraPreferita() {
		var index_squadra = $(this).attr('k_custom_id_squadra');
		
		var stato = 0;
		if ($(this).is(':checked') == true) {
			stato = 1;
		}
		
		var nome_squadra = "";
		classifiche.classifica.squadre.forEach(function(entry) {
			if(entry.index_squadra == index_squadra) {
				nome_squadra = entry.nome;
				return false;
			}
		});

		app.utils.SetPreferenzaSquadra(nome_squadra, stato);
		
		if(!stato) {
			app.utils.googleAnalytics('send', 'event', 'button click', 'Rimossa squadra: ' + nome_squadra + ' come preferita');
		} else {
			app.utils.googleAnalytics('send', 'event', 'button click', 'Aggiunta squadra: ' + nome_squadra + ' come preferita');
		}
	}

	function refreshResults() {
		app.f7.showIndicator();
		setTimeout(function() {
			app.f7.hideIndicator();
			loadClassifiche("", true);
		}, 1000);
	}

	function loadClassifiche(filter, refresh) {
		classifiche = [];
		tempInitializeStorage(filter, refresh);
	}

	function showClassifiche(temp_classifiche, filter, refresh) {
		if (filter) {
			temp_classifiche = _.filter(temp_classifiche, filter);
		}

		classifiche = temp_classifiche;
		
		ClassificheView.render({
			bindings : bindings,
			cuore : cuore,
			header : getHeader(),
			model : classifiche,
			modulo : modulo
		});
		if (refresh) {
			app.f7.pullToRefreshDone();

			app.f7.addNotification({
				title : 'Info',
				subtitle : '',
				message : getHeader() + ', dati aggiornati!',
				hold : 2000,
				media : '<i class="icon icon-refresh"></i>'
			});

			app.utils.googleAnalytics('send', 'event', 'list refresh', getHeader() + ', dati aggiornati!');
		}
	}

	function tempInitializeStorage(filter, refresh) {
		var temp_classifiche = [];
		$.ajax({
			method : "GET",
			async : true,
			url : app.utils.GetRisorsa(campionato),
			dataType : "xml",
			timeout: 15000,
			beforeSend : function(xhr, opts) {
				if(!app.utils.checkConnection()) {
					xhr.abort();
					app.utils.ajaxError();
				} else {
					app.f7.showIndicator();
				}
			},
			error : function() {
				app.utils.ajaxError();
			},
			success : function(data) {
				app.f7.hideIndicator();
				var squadre = [];
				
				$(data).find("SQUADRA").each(function(index, value) {
					var NomeSquadra = $(value).text();			
					var preferenza = app.utils.GetPreferenzaSquadra(NomeSquadra);
					
					var checked = false;					
					if(preferenza == "true") {
						checked = true;
					}
					
					// Fix squadra Forlì (per l'accento)
					var squadraPath = NomeSquadra.split(" ").pop();
					if(squadraPath == "Forli'") {
						squadraPath = "Forli";
					}
					
					squadre.push(new Squadra({
						nome : NomeSquadra,
						id_squadra : $(value).attr("IdSquadra"),
						posizione : $(value).attr("Posizione"),
						vinte : $(value).attr("Vinte"),
						perse : $(value).attr("Perse"),
						punti : $(value).attr("Punti"),
						index_squadra : index,
						squadra_preferita : checked,
						image : 'img/loghi_club/' + campionato + '/' + squadraPath + '.jpg'
					}));
				});
				temp_classifiche = new Classifica({
					"squadre" : squadre
				});

				showClassifiche(JSON.parse(JSON.stringify({
					classifica : temp_classifiche
				})), filter, refresh);
			}
		});
	}

	return {
		init : init
	};
});