define(["app", "js/models/canaleModel", "js/news/newsView", "text!js/homepage/list.html", "text!js/news/news-detail.html"], function(app, Canale, NewsView, ListTemplate, DetailTemplate) {
	var news = [];
	var sesso = "";
	var modulo = "";
	var bindings = [{
		element : '.news-item',
		event : 'click',
		handler : showItem
	}];

	function init(query) {
		if(app.utils.checkConnection() == true) {
			sesso = query.Sesso;
			modulo = query.modulo;
			app.utils.Log("INIT newsController");

			var compiled_template = Template7.compile(ListTemplate);
			var html = compiled_template({
				"modulo" : modulo,
				"notifiche" : app.utils.getClassNotifiche,
				"searchbar_hidden" : true
			});
			app.mainView.router.loadPage({
				content : html
			});

			app.f7.showIndicator();
			loadNews("", false);
			
			$('.pull-to-refresh-content' + '.' + modulo + '-refresh').bind('refresh', function(e) {
				e.stopPropagation();
				refreshResults();
			});

			$('#refresh_link_' + modulo).bind('click', function(e) {
				e.stopPropagation();
				refreshResults();
			});

			app.utils.googleAnalytics('send', 'pageview', {
				'page' : getHeader()
			});
		} else {
			app.utils.ajaxError();
		}	
	}

	function loadNews(filter, refresh) {
		news = [];
		tempInitializeStorage(filter, refresh);
	}

	function showNews(temp_news, filter, refresh) {
		if (filter) {
			temp_news = _.filter(temp_news, filter);
		}

		news = temp_news;

		NewsView.render({
			bindings : bindings,
			header : getHeader(),
			modulo : modulo,
			model : news
		});

		if (refresh) {
			app.f7.pullToRefreshDone();

			app.f7.addNotification({
				title : 'Info',
				subtitle : '',
				message : getHeader() + ', dati aggiornati!',
				hold : 2000,
				media : '<i class="icon icon-refresh"></i>'
			});

			app.utils.googleAnalytics('send', 'event', 'list refresh', getHeader() + ', dati aggiornati!');
		}
	}

	function getHeader() {
		var header = "";
		switch (sesso) {
			case "Femminile" :
				header = "Ultime News Femminile";
				break;
			case "" :
				header = "Ultime News";
				break;
			default :
				break;
		}
		return header;
	}

	function showItem() {
		var link = $(this).attr('k_custom_link');

		var id_str = link.split("=");
		var id_news = id_str[1];

		var data_news = "";
		news.news.items.forEach(function(entry) {
			if (entry.link_articolo == link) {
				data_news = entry.pubDate;
			}
		});

		// Data ottenuta dalla news
		var d = new Date(data_news);
		var curr_date = d.getDate();
		var curr_month = d.getMonth() + 1; // Months are zero based
		var curr_year = d.getFullYear();

		var curr_name_day = ["Domenica", "Lunedì", "Martedì", "Mercoledì", "Giovedì", "Venerdì", "Sabato"][d.getDay()];
		var monthNames = ["Gennaio", "Febbraio", "Marzo", "Aprile", "Maggio", "Giugno", "Luglio", "Agosto", "Settembre", "Ottobre", "Novembre", "Dicembre"];

		var curr_name_month = monthNames[d.getMonth()];
		var data_news_final = curr_name_day + " " + curr_date + ", " + curr_name_month + " " + curr_year;

		var url = app.utils.GetRisorsa("RssFeedLegaDettaglio");
		
		var tipo = "maschile";
		if (sesso == "Femminile") {
			tipo = "femminile";
		}
		
		$.ajax({
			method : "POST",
			async : true,
			url : url,
			data : {
				id : id_news,
				tipo : tipo
			},
			dataType : "json",
			timeout: 15000,
			beforeSend : function(xhr, opts) {
				if(!app.utils.checkConnection()) {
					xhr.abort();
					app.utils.ajaxError();
				} else {
					app.f7.showIndicator();
				}
			},
			error : function() {
				app.utils.ajaxError();
			},
			success : function(data) {
				var compiled_template = Template7.compile(DetailTemplate);
				var html = compiled_template({
					data : data.RESULT,
					"notifiche" : app.utils.getClassNotifiche,
					data_news : data_news_final
				});
				app.mainView.router.loadPage({
					content : html
				});
				
				app.utils.googleAnalytics('send', 'event', 'button click', 'News con ID: ' + id_news + ' visualizzata');
			}
		});
	}

	function refreshResults() {
		app.f7.showIndicator();
		setTimeout(function() {
			app.f7.hideIndicator();
			loadNews("", true);
		}, 1000);
	}

	function tempInitializeStorage(filter, refresh) {
		var temp_news = [];
		$.ajax({
			method : "GET",
			async : true,
			url : app.utils.GetRisorsa("RssFeedLega" + sesso),
			dataType : "xml",
			timeout: 15000,
			beforeSend : function(xhr, opts) {
				if(!app.utils.checkConnection()) {
					xhr.abort();
					app.utils.ajaxError();
				} else {
					app.f7.showIndicator();
				}
			},
			error : function() {
				app.utils.ajaxError();
			},
			success : function(data) {
				app.f7.hideIndicator();
				var items = [];
				$(data).find("item").each(function(index) {
					var link_articolo;
					if (sesso == "Femminile") {
						link_articolo = $(this).find("link").text().replace("NewsLeggi.asp", "NewsMobile.asp");
					} else {
						link_articolo = $(this).find("link").text();
					}
					items.push({
						titolo : $(this).find("titolo").text(),
						link_articolo : link_articolo,
						pubDate : $(this).find("pubDate").text(),
						description : $(this).find("description").text()
					});
				});
				temp_news = new Canale({
					items : items
				});

				showNews(JSON.parse(JSON.stringify({
					news : temp_news
				})), filter, refresh);
			}
		});
	}

	return {
		init : init
	};
});