define(["app", "js/models/classificaModel", "js/models/squadraModel", "js/notifiche/notificheView", "text!js/homepage/list.html"], function(app, Classifica, Squadra, NotificheView, ListTemplate) {
	var campionato = "";
	var modulo = "";
	var sesso = "";
	var filter = "";
	var filter_ID = "";
	var triggered = false;
	var classifiche = [];
	var bindings = [{
		element : '.selezione_notifiche_push',
		event : 'change',
		handler : setPushNotification
	}];

	function init(query) {
		campionato = query.Campionato;
		modulo = query.modulo;
		sesso = query.sesso;
		if (query.filter !== undefined) {
			filter = query.filter;
			filter_ID = query.filter_ID;
		} else {
			filter = "";
			filter_ID = "";
		}

		app.utils.Log("INIT classificheController");

		var compiled_template = Template7.compile(ListTemplate);
		var html = compiled_template({
			"modulo" : modulo,
			"refresh_hidden" : true,
			"notifiche" : app.utils.getClassNotifiche,
			"pulltorefresh_hidden" : true
		});
		app.mainView.router.loadPage({
			content : html
		});

		$('.' + modulo + '-refresh').removeClass('pull-to-refresh-content');

		app.f7.showIndicator();
		loadNotifiche(filter);

		app.utils.googleAnalytics('send', 'pageview', {
			'page' : getHeader()
		});
	}

	function setPushNotification(event) {
		var id = $(this).attr("id");

		var squadra;
		if (filter == "") {
			squadra = classifiche.classifica.squadre[id].nome;
		} else {
			squadra = classifiche.classifica.squadre[0].nome;
		}

		var evento = $(this).val();
		var xml = "";
		switch (sesso) {
			case "RealTime" :
				xml = 'maschile';
				break;
			case "RealTimeFemminile" :
				xml = 'femminile';
				break;
			default :
				xml = 'maschile';
				break;
		}

		app.utils.SetPushNotification(squadra, evento, xml, {
			filter : filter,
			filter_ID : filter_ID,
			id : id,
			mainView : app.mainView
		});
	}

	function loadNotifiche(filter) {
		classifiche = [];
		tempInitializeStorage(filter);
	}

	function getHeader() {
		var header = "";
		switch (campionato) {
			case "A1" :
				header = "Notifiche Regular Season A1";
				break;
			case "A2" :
				header = "Notifiche Regular Season A2";
				break;
			case "A1Femminile" :
				header = "Notifiche Regular Season A1 Femminile";
				break;
			case "A2Femminile" :
				header = "Notifiche Regular Season A2 Femminile";
				break;
			default :
				break;
		}
		return header;
	}

	function showNotifiche(temp_classifiche) {
		if (filter != "") {
			var found = false;
			var temp_found = {};

			temp_classifiche.classifica.squadre.forEach(function(entry) {
				if (entry.nome == filter) {
					found = true;
					temp_found = entry;
				}
			});

			temp_classifiche.classifica.squadre = [];
			if (found) {
				temp_classifiche.classifica.squadre.push(temp_found);
			}
			triggered = true;
		}

		classifiche = temp_classifiche;

		NotificheView.render({
			bindings : bindings,
			header : getHeader(),
			model : classifiche,
			app : app,
			triggered : triggered,
			found : found,
			modulo : modulo
		});
	}

	function tempInitializeStorage(filter) {
		var temp_classifiche = [];
		app.$$.ajax({
			method : "GET",
			async : true,
			url : app.utils.GetRisorsa(campionato),
			timeout: 15000,
			dataType : "xml",
			beforeSend : function(xhr, opts) {
				if(!app.utils.checkConnection()) {
					xhr.abort();
					app.utils.ajaxError();
				} else {
					app.f7.showIndicator();
				}
			},
			error : function() {
				app.utils.ajaxError();
			},
			success : function(data) {
				app.f7.hideIndicator();
				var squadre = [];

				$(data).find("SQUADRA").each(function(index, value) {
					var NomeSquadra = $(value).text();
					var notifica_val = app.utils.GetPushNotification(NomeSquadra);
					var notifica_lbl = "";
					switch (notifica_val) {
						case "None" :
							notifica_lbl = "Nessuna";
							break;
						case "Match" :
							notifica_lbl = "Partita";
							break;
						case "Set" :
							notifica_lbl = "Set";
							break;
						case "Point" :
							notifica_lbl = "Tutti i punti!";
							break;
					}

					var notifiche_list = "";
					var values = ["None", "Match", "Set", "Point"];
					$.each(values, function(index, value) {
						label = "";
						switch (value) {
							case "None" :
								label = "Nessuna";
								break;
							case "Match" :
								label = "Partita";
								break;
							case "Set" :
								label = "Set";
								break;
							case "Point" :
								label = "Tutti i punti!";
								break;
						}

						selected = "";
						if (value == notifica_val) {
							selected = 'selected="selected"';
						}

						notifiche_list += '<option value="' + value + '" ' + selected + '>' + label + '</option>';
					});
					
					// Fix squadra Forlì (per l'accento)
					var squadraPath = NomeSquadra.split(" ").pop();
					if(squadraPath == "Forli'") {
						squadraPath = "Forli";
					}

					squadre.push(new Squadra({
						nome : NomeSquadra,
						vinte : $(value).attr("Vinte"),
						perse : $(value).attr("Perse"),
						punti : $(value).attr("Punti"),
						index_squadra : index,
						notifica_val : notifica_val,
						notifica_lbl : notifica_lbl,
						notifiche_list : notifiche_list,
						image : 'img/loghi_club/' + campionato + '/' + squadraPath + '.jpg'
					}));
				});
				temp_classifiche = new Classifica({
					"squadre" : squadre
				});

				showNotifiche(JSON.parse(JSON.stringify({
					classifica : temp_classifiche
				})), filter);
			}
		});
	}

	return {
		init : init
	};
});